<?php
/**
 * Hide Content
 *
 * @package SMF
 * @author kelvincool
 * @copyright 2014 kelvincool
 * @license http://creativecommons.org/licenses/by/3.0 CC
 *
 * @version 1.1.4
 */

// No Direct Access!
if (!defined('SMF'))
	die('Hacking attempt...');

class HideContent
{
	public static function loadHideContentBBC(&$codes) {
		global $modSettings;
		if (!HideContent::checkEnabled()) {
			return;
		}
		$parameters = array();
		call_integration_hook('integrate_hide_content_implement_parameter', array(&$parameters));
		// Disable plugins no enabled
		foreach($parameters as $key=>$parameter) {
			if (empty($modSettings[$key . '_hidecontent_plugin'])) {
				// plugin has been disabled but let's just let it pass so we don't get the ugly bbc codes displayed
				$parameters[$key] = array('optional' => true);
			}
		}
		$validation = '
			$result = HideContent::evaluateConditions($data);
			if ($result) {
				$data = parse_bbc($data);
			}
		';
		$codes[] = array(
			'tag' => 'hide',
			'type' => 'unparsed_content',
			'parameters' => $parameters,
			'content' => '$1',
			'validate' => create_function('&$tag, &$data, $disabled', $validation)
		);
	}
	
	public static function loadHideContentBBCButton(&$tags) {
		global $txt, $context;
		if (!HideContent::checkEnabled() || HideContent::notAllowedTo()) {
			return;
		}
		$plugins = HideContent::getPlugins();
		$attributes = "";
		foreach($plugins as $key=>$plugin) {
			$attributes .= ' ' . $key . '=' . $plugin['default_value'];
		}
		if ($attributes != "") {
			$tags[count($tags)-1][] = array(
				'image' => 'hide',
				'code' => 'hide',
				'before' => '[hide' . $attributes . ']',
				'after' => '[/hide]',
				'description' => $txt['hidecontent_hide']
			);
		}
	}
	
	public static function loadTheme() {
		global $context;
		
		if (!empty($context['current_topic']) || $context['current_action'] == 'search2') {
			loadTemplate('HideContent', 'hidecontent');
		}
		
		// load modal on post page and pm page
		if (($context['current_action'] == 'post' || $context['current_action'] == 'post2' || $context['current_action'] == 'pm') && !isset($_REQUEST['xml'])) {
			loadTemplate('HideContent', 'hidecontent');
			if (!HideContent::notAllowedTo()) {
				$context['html_headers'] .= template_hidecontent_js();
				$context['template_layers'][] = 'hidecontent';
			}
		}
		
		if ($context['current_action'] == 'post' && !empty($_REQUEST['quote'])) {
			$context['template_layers'][] = 'hidecontentquote';
		}
		
		if ($context['current_action'] == 'pm' && isset($_REQUEST['quote'])) {
			$context['template_layers'][] = 'hidecontentquote';
		}

		if ($context['current_action'] == 'admin' && $context['current_subaction'] == 'hidecontent') {
			loadTemplate('HideContent', 'hidecontent');
		}

		if ($context['current_action'] == 'admin' && $context['current_subaction'] == 'uninstall') {
			if (!empty($_REQUEST['package']) && substr($_REQUEST['package'], 0, 11) == 'HideContent') {
				loadTemplate('HideContent', 'hidecontent');
				$context['template_layers'][] = 'hidecontent_uninstall';
			}
		}
	}
	
	public static function evaluateConditions(&$data) {
		global $txt, $context, $messages_request, $smcFunc;
		$results = array();
		$errorMessage = '';
		$canModify = false;
		$message = array(
			'id_member' => -1,
		);
		$plugins = HideContent::getPlugins();
		foreach($plugins as $key=>$plugin) {
			$result = call_user_func($plugin['evaluate']);
			if (!empty($result)) {
				$results[] = $result;
			}
			call_user_func($plugin['reset']);
		}
		if (!empty($context['hc_current_post'])) {
			// parsing the previous posts now
			$message = $context['hc_current_post'];
			// handle previewing
			if ($context['hc_current_post'] === "preview") {
				$data = template_hidecontent_wrapper($data);
				return true;
			}
		}
		// handle quoting
		else if (isset($_REQUEST['quote'])) {
			$data = $txt['hidecontent_quote_hidden'];
			return false;
		}
		loadTemplate('HideContent', 'hidecontent');
		// check if admin/mod or owner
		$canView = HideContent::checkPermission($message);
		if (count($results) > 0 && !$canView) {
			$errorMessage = template_hidecontent_error_wrapper($results);
			$data = $errorMessage;
			return false;
		}
		$data = template_hidecontent_wrapper($data);
		return true;
	}
	
	public static function setManagement(&$subActions) {
		$subActions['hidecontent'] = 'ModifyHideContentSettings';
	}
	
	public static function setAdminArea(&$admin_areas) {
		global $txt;
		$admin_areas['config']['areas']['modsettings']['subsections']['hidecontent'] = array($txt['hidecontent_settings']);
	}
	
	public static function getPlugins() {
		global $modSettings;
		$plugins = array();
		call_integration_hook('integrate_hide_content_plugin_info', array(&$plugins));
		foreach($plugins as $key=>$plugin) {
			if (empty($modSettings[$key . '_hidecontent_plugin'])) {
				unset($plugins[$key]);
			}
		}
		return $plugins;
	}
	
	public static function getPluginsOptions($plugin) {
		global $modSettings;
		$options = call_user_func($plugin['options']);
		$default_key = $plugin['code'] . '_hidecontent_plugin_default_value';
		if (!empty($modSettings[$default_key])) {
			if ($options['type'] == 'checkbox') {
				if ($modSettings[$default_key]) {
					$options['default_value'] = explode(',', $modSettings[$default_key]);
				}
			}
			else {
				$options['default_value'] = $modSettings[$default_key];
			}
		}
		return $options;
	}
	
	public static function handleQuoteFast() {
		global $context, $modSettings;
		if (!empty($context['quote'])) {
			$autoLinkUrlsSetting = $modSettings['autoLinkUrls'];
			$modSettings['autoLinkUrls'] = "";
			$context['quote']['xml'] = parse_bbc($context['quote']['xml'], false, '', array('hide'));
			$modSettings['autoLinkUrls'] = $autoLinkUrlsSetting;
			$context['quote']['xml'] = strtr($context['quote']['xml'], array(' &nbsp;' => '  ', '<br />' => "\n", '<br />&nbsp;' => "\n ", "\n" => '&#13;'));
		}
	}
	
	public static function handleQuote() {
		global $context, $modSettings;
		$context['quoteprocess'] = false;
		$autoLinkUrlsSetting = $modSettings['autoLinkUrls'];
		$modSettings['autoLinkUrls'] = "";
		$context['message'] = parse_bbc($context['message'], false, '', array('hide'));
		$modSettings['autoLinkUrls'] = $autoLinkUrlsSetting;
		$context['controls']['richedit']['message']['rich_value'] = $context['message'];
		$context['message'] = strtr($context['message'], array(' &nbsp;' => '  ', '<br />' => "\n", '<br />&nbsp;' => "\n ", "\n" => '&#13;'));
		$context['controls']['richedit']['message']['value'] = $context['message'];
		$context['quoteprocess'] = true;
	}
	
	public static function checkPermission($message) {
		global $context, $user_info;
		// mostly copied from prepareDisplayContext in Subs.php
		return (allowedTo('moderate_board') || allowedTo('modify_any') || (allowedTo('modify_replies') && !empty($context['user']['started'])) || ($message['id_member'] == $user_info['id']));
	}
	
	public static function checkEnabled() {
		global $context, $modSettings;
		
		// handle PM page
		if (!empty($context['current_action']) && $context['current_action'] == 'pm') {
			if (!empty($modSettings['hc_disable_on_pm'])) {
				return false;
			}
			return true;
		}
		
		// handle topic page, reply and new topic
		if (!empty($context['current_board'])) {
			if (!empty($modSettings['hc_disable_on_boards'])) {
					$boardsDisabled = unserialize($modSettings['hc_disable_on_boards']);
					if (in_array($context['current_board'], $boardsDisabled)) {
						return false;
					}
			}
		}
		
		// let it through on any other page like rss, recent posts, profile, etc...
		return true;
	}
	
	public static function loadPermissions(&$permissionGroups, &$permissionList, &$leftPermissionGroups, &$hiddenPermissions, &$relabelPermissions) {
		$permissionList['membergroup']['pm_hide_content'] = array(false, 'pm', 'use_pm_system');
		$permissionList['board']['hide_content'] = array(false, 'post', 'make_posts');
	}
	
	public static function notAllowedTo() {
		global $context;
		// not allowed to hide content and on any page but pm or not allowed to hide content in pm and on the pm page
		return (!allowedTo('hide_content') && $context['current_action'] != 'pm') || (!allowedTo('pm_hide_content') && $context['current_action'] == 'pm');
	}
}