<?php
/**
 * Hide Content
 *
 * @package SMF
 * @author kelvincool
 * @copyright 2014 kelvincool
 * @license http://creativecommons.org/licenses/by/3.0 CC
 *
 * @version 1.0
 */

// No Direct Access!
if (!defined('SMF'))
	die('Hacking attempt...');

class HideKarma
{
	private static $karma = null;
	
	public static function reset() {
		self::$karma = null;
	}
	
	public static function setKarma($count) {
		self::$karma = intval($count);
	}
	
	public static function getKarma() {
		return self::$karma;
	}
	
	public static function getPluginInfo(&$plugins) {
		global $txt;
		$plugins['karma'] = array(
			'title' => $txt['hidekarma_title'], 
			'code' => 'karma', 
			'default_value' => 0, 
			'description' => $txt['hidekarma_desc'], 
			'evaluate' => 'HideKarma::evaluateCondition', 
			'options' => 'HideKarma::getOptions',
			'reset' => 'HideKarma::reset'
		);
	}
	
	public static function setParameter(&$parameters) {
		$parameters['karma'] = array(
			'optional' => true, 
			'match' => '([-\d]+)', 
			'validate' => create_function('&$data', 'HideKarma::setKarma($data);')
		);
	}
	
	public static function evaluateCondition() {
		global $txt, $user_info, $smcFunc;
		$result = '';
		$karma_needed = HideKarma::getKarma();
		if ($karma_needed === null) {
			return $result;
		}
		$query = $smcFunc['db_query']('', '
			SELECT m.karma_bad, m.karma_good
			FROM {db_prefix}members m
			WHERE m.id_member = {int:id_member}',
			array(
				'id_member' => $user_info['id'],
			)
		);
		$row = $smcFunc['db_fetch_assoc']($query);
		$karma = $row['karma_good'] - $row['karma_bad'];
		if ($karma_needed > $karma) {
			$result = strtr($txt['hidekarma_text'], array('{karma_needed}' => '<strong>' . $karma_needed . '</strong>'));
		}
		return $result;
	}
	
	public static function getOptions() {
		global $txt;
		$options = array(
			'type' => 'text', 
			'title' => $txt['hidekarma_input_title'], 
			'id' => 'karma', 
			'default_value' => 0, 
			'class' => 'numeric'
		);
		return $options;
	}
}