<?php
/**
 * Hide Content
 *
 * @package SMF
 * @author kelvincool
 * @copyright 2014 kelvincool
 * @license http://creativecommons.org/licenses/by/3.0 CC
 *
 * @version 1.1.3
 */

// No Direct Access!
if (!defined('SMF'))
	die('Hacking attempt...');

class HideLogin
{
	private static $is_logged_in = null;
	
	public static function reset() {
		self::$is_logged_in = null;
	}
	
	public static function setIsLoggedIn($data) {
		$is_logged_in = true;
		if (intval($data) == 0) {
			$is_logged_in = false;
		}
		self::$is_logged_in = $is_logged_in;
	}
	
	public static function isLoggedIn() {
		return self::$is_logged_in;
	}
	
	public static function getPluginInfo(&$plugins) {
		global $txt;
		$plugins['login'] = array(
			'title' => $txt['hidelogin_title'], 
			'code' => 'login', 
			'default_value' => 1, 
			'description' => $txt['hidelogin_desc'], 
			'evaluate' => 'HideLogin::evaluateCondition', 
			'options' => 'HideLogin::getOptions',
			'reset' => 'HideLogin::reset'
		);
	}
	
	public static function setParameter(&$parameters) {
		$parameters['login'] = array(
			'optional' => true, 
			'match' => '(\d)', 
			'validate' => create_function('&$data', 'HideLogin::setIsLoggedIn($data);')
		);
	}
	
	public static function evaluateCondition() {
		global $txt, $user_info, $context, $scripturl;
		$result = '';
		$is_logged_in = HideLogin::isLoggedIn();
		if ($is_logged_in === null) {
			return $result;
		}
		if (!$is_logged_in && !$user_info["is_guest"]) {
			$result = strtr($txt['hidelogin_only_for_guest_text'], array(
				'{logout_link}' => $scripturl . '?action=logout;' . $context['session_var'] . '=' . $context['session_id'],
			));
		}
		else if ($is_logged_in && $user_info["is_guest"]) {
			$result = strtr($txt['hidelogin_only_for_registered_text'], array(
				'{login_link}' => $scripturl . '?action=login',
				'{register_link}' => $scripturl . '?action=register',
			));
		}
		return $result;
	}
	
	public static function getOptions() {
		global $txt;
		$options = array(
			'type' => 'hidden', 
			'title' => '', 
			'id' => 'login_input', 
			'default_value' => 1
		);
		return $options;
	}
}