<?php
/**
 * Hide Content
 *
 * @package SMF
 * @author kelvincool
 * @copyright 2014 kelvincool
 * @license http://creativecommons.org/licenses/by/3.0 CC
 *
 * @version 1.1
 */

// No Direct Access!
if (!defined('SMF'))
	die('Hacking attempt...');

class HidePost
{
	private static $post_count = 0;
	
	public static function reset() {
		self::$post_count = 0;
	}
	
	public static function setPostCount($count) {
		self::$post_count = intval($count);
	}
	
	public static function getPostCount() {
		return self::$post_count;
	}
	
	public static function getPluginInfo(&$plugins) {
		global $txt;
		$plugins['post'] = array(
			'title' => $txt['hidepost_title'], 
			'code' => 'post', 
			'default_value' => 1, 
			'description' => $txt['hidepost_desc'], 
			'evaluate' => 'HidePost::evaluateCondition', 
			'options' => 'HidePost::getOptions',
			'reset' => 'HidePost::reset'
		);
	}
	
	public static function setParameter(&$parameters) {
		$parameters['post'] = array(
			'optional' => true, 
			'match' => '(\d+)', 
			'validate' => create_function('&$data', 'HidePost::setPostCount($data);')
		);
	}
	
	public static function evaluateCondition() {
		global $txt, $user_info;
		$result = '';
		$posts_needed = HidePost::getPostCount();
		if ($posts_needed === 0) {
			return $result;
		}
		if ($posts_needed > $user_info["posts"] || $user_info["is_guest"]) {
			$posts_left = $posts_needed - $user_info["posts"];
			$result = strtr($txt['hidepost_text'], array(
				'{posts_needed}' => '<strong>' . $posts_needed . '</strong>',
				'{posts_left}' => '<strong>' . $posts_left . '</strong>',
			));
		}
		return $result;
	}
	
	public static function getOptions() {
		global $txt;
		$options = array(
			'type' => 'text', 
			'title' => $txt['hidepost_input_title'], 
			'id' => 'post_count', 
			'default_value' => 1, 
			'class' => 'numeric'
		);
		return $options;
	}
}