<?php
/**
 * Hide Content
 *
 * @package SMF
 * @author kelvincool
 * @copyright 2014 kelvincool
 * @license http://creativecommons.org/licenses/by/3.0 CC
 *
 * @version 1.1.3
 */

// If SSI.php is in the same place as this file, and SMF isn't defined, this is being run standalone.
if (!defined('SMF') && file_exists(dirname(__FILE__) . '/SSI.php'))
	require_once(dirname(__FILE__) . '/SSI.php');
// Hmm... no SSI.php and no SMF?
elseif(!defined('SMF'))
	die('<b>Error:</b> Cannot install - please verify you put this in the same place as SMF\'s index.php.');

// Add hooks (for 2.0)
if (!empty($smcFunc['db_query']))
{
	db_extend('packages');
	
	$sef_functions = array(
		'integrate_bbc_codes' => 'HideContent::loadHideContentBBC',
		'integrate_bbc_buttons' => 'HideContent::loadHideContentBBCButton',
		'integrate_load_theme' => 'HideContent::loadTheme',
		'integrate_pre_include' => $sourcedir . '/HideContent.php',
		'integrate_modify_modifications' => 'HideContent::setManagement',
		'integrate_admin_areas' => 'HideContent::setAdminArea',
		'integrate_load_permissions' => 'HideContent::loadPermissions',
	);
	
	foreach ($sef_functions as $hook => $function)
		add_integration_function($hook, $function, TRUE);
		
	$sef_functions = array(
		'integrate_pre_include' => $sourcedir . '/HidePost.php',
		'integrate_hide_content_implement_parameter' => 'HidePost::setParameter',
		'integrate_hide_content_plugin_info' => 'HidePost::getPluginInfo',
	);
	foreach ($sef_functions as $hook => $function)
		add_integration_function($hook, $function, TRUE);
		
	$sef_functions = array(
		'integrate_pre_include' => $sourcedir . '/HideLogin.php',
		'integrate_hide_content_implement_parameter' => 'HideLogin::setParameter',
		'integrate_hide_content_plugin_info' => 'HideLogin::getPluginInfo',
	);
	foreach ($sef_functions as $hook => $function)
		add_integration_function($hook, $function, TRUE);
		
	$sef_functions = array(
		'integrate_pre_include' => $sourcedir . '/HideGroup.php',
		'integrate_hide_content_implement_parameter' => 'HideGroup::setParameter',
		'integrate_hide_content_plugin_info' => 'HideGroup::getPluginInfo',
	);
	foreach ($sef_functions as $hook => $function)
		add_integration_function($hook, $function, TRUE);
		
	$sef_functions = array(
		'integrate_pre_include' => $sourcedir . '/HideKarma.php',
		'integrate_hide_content_implement_parameter' => 'HideKarma::setParameter',
		'integrate_hide_content_plugin_info' => 'HideKarma::getPluginInfo',
	);
	foreach ($sef_functions as $hook => $function)
		add_integration_function($hook, $function, TRUE);
	
	global $smcFunc;
	$permissions_exist = false;

	$request = $smcFunc['db_query']('', '
		SELECT count(id_group) as total
		FROM {db_prefix}permissions
		WHERE permission = {string:permission}',
		array(
			'permission' => 'pm_hide_content'
		)
	);
	$permissions_check = $smcFunc['db_fetch_assoc']($request);
	$smcFunc['db_free_result']($request);
	if (!empty($permissions_check)) {
		if ($permissions_check['total'] > 0) {
			$permissions_exist = true;
		}
	}
	
	if (!$permissions_exist) {
		$request = $smcFunc['db_query']('', '
			SELECT count(id_group) as total
			FROM {db_prefix}board_permissions
			WHERE permission = {string:permission}',
			array(
				'permission' => 'hide_content'
			)
		);
		$board_permissions_check = $smcFunc['db_fetch_assoc']($request);
		$smcFunc['db_free_result']($request);
		if (!empty($board_permissions_check)) {
			if ($board_permissions_check['total'] > 0) {
				$permissions_exist = true;
			}
		}
	}
	
	// default permissions for first install
	if (!$permissions_exist) {
		// Get all the non-postcount based groups.
		$request = $smcFunc['db_query']('', '
			SELECT id_group
			FROM {db_prefix}membergroups
			WHERE min_posts = -1'
		);
		$groups = array();
		$groups[] = array('id_group' => 0, 'permission' => 'pm_hide_content', 'add_deny' => 1);
		$board_groups = array();
		$board_groups[] = array('id_group' => 0, 'id_profile' => 1, 'permission' => 'hide_content', 'add_deny' => 1);
		while ($row = $smcFunc['db_fetch_assoc']($request))
		{
			$groups[] = array('id_group' => $row['id_group'], 'permission' => 'pm_hide_content', 'add_deny' => 1);
			$board_groups[] = array('id_group' => $row['id_group'], 'id_profile' => 1, 'permission' => 'hide_content', 'add_deny' => 1);
		}
		$smcFunc['db_free_result']($request);

			// Insert permission for all groups
		$smcFunc['db_insert']('ignore' ,
			'{db_prefix}permissions',
			array(
				'id_group' => 'int', 'permission' => 'string', 'add_deny' => 'int'
			),
			$groups,
			array('id_group', 'permission')
		);
		
		// Insert permission for all groups
		$smcFunc['db_insert']('ignore' ,
			'{db_prefix}board_permissions',
			array(
				'id_group' => 'int', 'id_profile' => 'int', 'permission' => 'string', 'add_deny' => 'int'
			),
			$board_groups,
			array('id_group', 'id_profile', 'permission')
		);
	}
}