/**
 * Hide Content
 *
 * @package SMF
 * @author kelvincool
 * @copyright 2014 kelvincool
 * @license http://creativecommons.org/licenses/by/3.0 CC
 *
 * @version 1.1.4
 */

function hidecontent() {
	this.init();
}

/**
 *	Initialize variables and listeners.
 */
hidecontent.prototype.init = function() {
	oEditorHandle_message.oSmfExec.hide = 'hideOptions';
	this.oModalWrapper = document.getElementById('hidecontent_modal_wrapper');

	var oModalSubmit = document.getElementById('hidecontent_submit_button');
	oModalSubmit.instanceRef = this;
	oModalSubmit.onclick = function () {
		this.instanceRef.handleModalSubmitClick();
		return false;
	};

	var oCloseButton = document.getElementById('hidecontent_close_button');
	oCloseButton.instanceRef = this;
	oCloseButton.onclick = function () {
		this.instanceRef.handleModalCloseClick();
		return false;
	};
	
	this.oPlugins = document.getElementsByClassName('hidecontent_option_wrapper');
	for (i = 0; i < this.oPlugins.length; ++i) {
		var oPlugin = this.oPlugins[i];
		var oSelectButton = oPlugin.getElementsByTagName('input')[1];
		if (oSelectButton.className == 'input_check') {
			oSelectButton.instanceRef = this;
			oSelectButton.onclick = function () {
				this.instanceRef.handleOptionClick(this);
			};
		}
	}
	
	// Get template for error messages
	this.oModalErrors = document.getElementById('modal_errors');
	this.sErrorsMessagesTemplate1 = document.getElementById('modal_error_required').innerHTML;
	this.sErrorsMessagesTemplate2 = document.getElementById('modal_error_numeric').innerHTML;
	this.sErrorsMessagesTemplate3 = document.getElementById('modal_error_plugin_required').innerHTML;
	
	this.resetHiddenPluginOptions();

	// Toggle modal
	smc_Editor.prototype.hideOptions = function()
	{
		var oModalWrapper = document.getElementById('hidecontent_modal_wrapper');
		var oModalWindow = document.getElementById('hidecontent_modal_window');
		oModalWrapper.className = 'overlay';
		oModalWindow.style.marginTop = (-oModalWindow.offsetHeight)/2 + 'px';
		oModalWindow.style.marginLeft = (-oModalWindow.offsetWidth)/2 + 'px';
		return true;
	}
}

/**
 *	Show and hide parameters.
 */
hidecontent.prototype.handleOptionClick = function (oInput)
{
	var oOptionParameters = oInput.parentNode.parentNode.getElementsByClassName('hidecontent_option_parameters')[0];
	if (oOptionParameters != null) {
		if (oInput.checked === false) { // checking prior state to being clicked
			this.addClassModalField('hide', oOptionParameters);
		}
		else {
			this.removeClassModalField('hide', oOptionParameters);
		}
	}
}

/**
 *	Process close action on modal.
 */
hidecontent.prototype.handleModalCloseClick = function ()
{
	this.oModalWrapper.className = "";
}

/**
 *	Process a submission.
 */
hidecontent.prototype.handleModalSubmitClick = function ()
{
	this.resetErrors();
	var aAttributes = {};
	var bOptionSelected = false;
	var aErrorsMessages = [];
	for (i = 0; i < this.oPlugins.length; ++i) {
		var oPlugin = this.oPlugins[i];
		var oOptionButton = oPlugin.getElementsByTagName('input')[1];
		if (oOptionButton.className == 'input_check') {
			if (oOptionButton.checked === true) {
				var sAttributeTag = oPlugin.getElementsByTagName('input')[0].value;
				var oParameters = oPlugin.getElementsByClassName('hidecontent_option_parameters')[0];
				var sAttributeValue = "";
				if (oParameters != null) {
					var oLegend = oParameters.getElementsByTagName('legend')[0];
					var oOptionsSelected = oParameters.getElementsByTagName('input');
					var oOptionsDropDownSelected = oParameters.getElementsByTagName('select');
					if (oOptionsSelected.length > 0 || oOptionsDropDownSelected.length > 0) {
						var oFirstInput = null;
						if (oOptionsDropDownSelected.length > 0) {
							oFirstInput = oOptionsDropDownSelected[0];
							sAttributeValue = oFirstInput.value;
						}
						else {
							oFirstInput = oOptionsSelected[0];
							if (oFirstInput.type == 'checkbox') {
								for (j = 0; j < oOptionsSelected.length; j++) {
									if (oOptionsSelected[j].checked === true) {
										sAttributeValue = sAttributeValue + oOptionsSelected[j].value + ',';
									}
								}
								oFirstInput = oFirstInput.parentNode.parentNode.parentNode;
							}
							else if (oFirstInput.type == 'text' || oFirstInput.type == 'hidden') {
								sAttributeValue = oFirstInput.value;
							}
						}
						sAttributeValue = sAttributeValue.replace(/,+$/,"");
						if (sAttributeValue == '') {
							aErrorsMessages.push(this.sErrorsMessagesTemplate1.replace('%field',  oLegend.innerHTML));
							this.addClassModalField('modal_error', oFirstInput);
						}
						else if (this.validateModalField(sAttributeValue, oFirstInput) === false) {
							aErrorsMessages.push(this.sErrorsMessagesTemplate2.replace('%field',  oLegend.innerHTML));
							this.addClassModalField('modal_error', oFirstInput);
						}
					}
					oOptionsSelected = oParameters.getElementsByTagName('select');
					if (oOptionsSelected.length > 0) {
						sAttributeValue = oOptionsSelected[0].value;
					}
				}
				bOptionSelected = true;
				aAttributes[sAttributeTag] = sAttributeValue;
			}
		}
	}
	if (bOptionSelected === false) {
		aErrorsMessages.push(this.sErrorsMessagesTemplate3);
	}

	if (aErrorsMessages.length > 0) {
		var sModalOverallError = '';
		for (var sError in aErrorsMessages) {
			sModalOverallError = sModalOverallError + aErrorsMessages[sError] + '<br />';
		}
		document.getElementById('modal_error_list').innerHTML = sModalOverallError;
		this.removeClassModalField('hide', this.oModalErrors);
	}
	else {
		var sAttributeString = '';
		for (var key in aAttributes) {
			if (aAttributes[key] == '') {
				sAttributeString = sAttributeString + key + ' ';
			}
			else {
				sAttributeString = sAttributeString + key + '=' + aAttributes[key] + ' ';
			}
		}
		sAttributeString = sAttributeString.replace(/\s+$/,"");
		surroundText('[hide ' + sAttributeString + ']'.replace(/\\n/g, '\n'), '[/hide]'.replace(/\\n/g, '\n'), oEditorHandle_message.oTextHandle);
		this.handleModalCloseClick();
		document.getElementById('modal_error_list').innerHtml = '';
		this.resetErrors();
	}
}

/**
 *	Validate input is numeric.
 */
hidecontent.prototype.validateModalField = function (sAttributeValue, oInput) {
	if (oInput.className.indexOf('numeric') > -1 && !((sAttributeValue - parseFloat( sAttributeValue ) + 1) >= 0)) {
		return false;
	}
	return true;
}

/**
 *	Add a class to the specified object.
 */
hidecontent.prototype.addClassModalField = function (sClassName, oInput) {
	sClassName = ' ' + sClassName + ' ';
	if (!(oInput.className.indexOf(sClassName) > -1)) {
		oInput.className = oInput.className + sClassName;
	}
}

/**
 *	Remove a class from the specified object.
 */
hidecontent.prototype.removeClassModalField = function (sClassName, oInput) {
	sClassName = ' ' + sClassName + ' ';
	if (oInput.className.indexOf(sClassName) > -1) {
		oInput.className = oInput.className.replace(sClassName, '');
	}
}

/**
 *	Reset the error.
 */
hidecontent.prototype.resetErrors = function () {
	// clean out fields still marked with error
	var oTaggedErrors = document.getElementsByClassName('modal_error');
	for (k = oTaggedErrors.length - 1; k > -1; k--) {
		this.removeClassModalField('modal_error', oTaggedErrors[k]);
	}
	this.addClassModalField('hide', this.oModalErrors);
}

/**
 *	Reset the parameter div to hidden if required.
 */
hidecontent.prototype.resetHiddenPluginOptions = function () {
	for (i = 0; i < this.oPlugins.length; ++i) {
		var oPlugin = this.oPlugins[i];
		var oOptionButton = oPlugin.getElementsByTagName('input')[1];
		var oParameters = oPlugin.getElementsByClassName('hidecontent_option_parameters')[0];
		if (oOptionButton.className == 'input_check') {
			if (oOptionButton.checked === true) {
				this.removeClassModalField('hide', oParameters);
			}
			else {
				this.addClassModalField('hide', oParameters);
			}
		}
	}
}

